%     Ventricular action potential model ORdmJ
%     Copyright (C) 2020 Jordi Llopis. Contact: jorllolo@etsii.upv.es
% 
%     This program is free software: you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation, either version 3 of the License, or
%     (at your option) any later version.
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <https://www.gnu.org/licenses/>

function [ time,X,IsJs] = modelRunner(parameters)
% This function simulates the action potential model with various parameters
% INPUTS:
% parameters: an structure array containing numbers of beats of the
% simulation, cycle length, initial conditions, cell type, drug
% concentration...
% OUTPUTS:
% time - a vector; the i-th element gives the timeline of the i-th
% action potential
%
% X - a matrix; the i-th element gives the matrix of state variables
% (#rows = length of time vector, columns are state variables).
%
% IsJs - a matrix; the i-th element gives the matrix of ionic currents
% values (#rows = length of time vector, columns are currents).

beats=parameters.beats; CL=parameters.CL;
X0=parameters.X0;
options=parameters.options;
celltype=parameters.celltype;
[block] = calculateBlock(parameters);
 
    for n=1:beats
            [time, X]=ode15s(@ORdmJ,[0 CL],X0,options,1,block,celltype);
            X0=X(end,:);
    end

for i=1:size(X,1)
    IsJs(i,:) = ORdmJ(time(i),X(i,:),0,block,celltype);
end
end