%     Ventricular action potential model ORdmJ
%     Copyright (C) 2020 Jordi Llopis. Contact: jorllolo@etsii.upv.es
% 
%     This program is free software: you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation, either version 3 of the License, or
%     (at your option) any later version.
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <https://www.gnu.org/licenses/>

function [ time_out,X_out, IsJs_out ] = runEADprotocol(parameters)
% This function reproduces the simulation protocol for generating an EAD:
% 999 stimulis at a 1 Hz, then a 2000 ms pause is left and an extra stimuli
% is applied
% The outputs contain information (time, state variables and currents) for
% the last 3 beats)

CL=1000;
CL2=2000;
X0=parameters.X0;
options=parameters.options;
celltype=parameters.celltype;
[block] = calculateBlock(parameters);
%% 999 first beats
    for n=1:999-1
            [time, X]=ode15s(@ORdmJ,[0 CL],X0,options,1,block,celltype);
            X0=X(end,:);
    end
    for m=[1:size(X,1)]
        IsJs(m,:)=ORdmJ(time(m),X(m,:),0,block,celltype);
    end
%% Beats 1000 and 1001
X_out=X;time_out=time;j=1;
IsJs_out=IsJs;
    for n=1:2
            [time, X]=ode15s(@ORdmJ,[0 CL2],X0,options,1,block,celltype);
            time_out=[time_out;time+(2*j-1)*CL];
            X_out=[X_out;X];
            X0=X(end,:);
            j=j+1;
    end
    for m=[1:size(X,1)]
        IsJs(m,:)=ORdmJ(time(m),X(m,:),0,block,celltype);
        IsJs_out=[IsJs_out;IsJs];
    end
end